@@ -156,15 +156,15 @@ class Connection(object):
                 )
             self.session.headers["Cookie"] = None
             self.email = email
-            if token is not None:
-                self.token = token
-                if bearer_token is not None:
+            if bearer_token is not None:
+                if token is not None:
                     warnings.warn(
                         "User token and bearer token authentication"
-                        "is mutually exclusive. Ignoring bearer token"
+                        "is mutually exclusive. Ignoring user token"
                     )
-            elif bearer_token is not None:
                 self.bearer_token = bearer_token
+            elif token is not None:
+                self.token = token
             self.update_session_auth()
 
         # Initialize feature groups
@@ -310,25 +310,29 @@ class Connection(object):
         self._rsa_key = value
         self.load_rsa_secret()
 
+    def get_container(self, container_id):
+        route = self.get_route(
+            "get_container", org_id=self.organization_id, container_id=container_id
+        )
+        return self.get(route)
+
     def save(self, path):
         """Saves current connection into specified file, used for CLI"""
         with open(os.path.expanduser(path), "w") as f:
-            f.write(
-                json.dumps(
-                    {
-                        "email": self.email,
-                        "token": self.token,
-                        "organization_id": self.organization_id,
-                        "api_root": self.api_root,
-                        "analytics": self.analytics,
-                        "user_id": self.user_id,
-                        "feature_groups": self.feature_groups,
-                        # We dont want to save a string key, only a path
-                        "rsa_key": self._rsa_key_path,
-                    },
-                    indent=2,
-                )
-            )
+            config_params = {
+                "email": self.email,
+                "token": self.token,
+                "organization_id": self.organization_id,
+                "api_root": self.api_root,
+                "analytics": self.analytics,
+                "user_id": self.user_id,
+                "feature_groups": self.feature_groups,
+            }
+            # We dont want to save a string key, only a path
+            if self._rsa_key is not None:
+                config_params["rsa_key"] = self._rsa_key_path
+
+            f.write(json.dumps(config_params, indent=2))
 
     def load_rsa_secret(self):
         key_string_or_path = self._rsa_key
@@ -449,13 +453,23 @@ class Connection(object):
         err_default = (
             f"There was an error fetching the runs in project " f"{project_id}"
         )
-        return self.get(
-            route,
-            status_response={
-                "200": lambda resp: resp.json(),
-                "default": lambda resp: RuntimeError(err_default),
-            },
-        )
+        results = []
+        while True:
+            response = self.get(
+                route,
+                status_response={
+                    "200": lambda resp: resp.json(),
+                    "default": lambda resp: RuntimeError(err_default),
+                },
+            )
+            results.extend(
+                [{**data["attributes"], "id": data["id"]} for data in response["data"]]
+            )
+            if "next" in response["links"]:
+                route = response["links"]["next"]
+            else:
+                break
+        return results
 
     def create_project(self, title):
         """Create project with given title"""
